@@ -62,7 +62,12 @@ def get_provisioned_product_from_scan(
 
 
 def terminate_if_status_is_not_available(
-    service_catalog, provisioned_product_name, product_id, account_id, region
+    service_catalog,
+    provisioned_product_name,
+    product_id,
+    account_id,
+    region,
+    should_delete_rollback_complete_stacks,
 ):
     prefix = f"[{provisioned_product_name}] {account_id}:{region}"
     logger.info(f"{prefix} :: checking if should be terminated")
@@ -97,6 +102,7 @@ def terminate_if_status_is_not_available(
                         product_id,
                         account_id,
                         region,
+                        should_delete_rollback_complete_stacks,
                     )
 
         elif current_status == "ERROR":
@@ -106,6 +112,17 @@ def terminate_if_status_is_not_available(
             terminate_provisioned_product(
                 prefix, service_catalog, provisioned_product.get("Id")
             )
+
+        elif (
+            current_status == "ROLLBACK_COMPLETE"
+            and should_delete_rollback_complete_stacks
+        ):
+            logger.info(
+                f"{prefix} :: should_delete_rollback_complete_stacks so terminating {provisioned_product.get('Status')}"
+            )
+            terminate_provisioned_product(
+                prefix, service_catalog, provisioned_product.get("Id")
+            )
     logger.info(f"{prefix} :: Finished terminate_if_status_is_not_available")
     return provisioned_product_id, provisioning_artifact_id, current_status
 
